=======================
 Invenio-Mail v1.0.0a3
=======================

Invenio-Mail v1.0.0a3 was released on February 25, 2016.

About
-----

Invenio mail module.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-mail==1.0.0a3

Documentation
-------------

   http://pythonhosted.org/invenio-mail/

Happy hacking and thanks for flying Invenio-Mail.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-mail
|   URL: http://invenio-software.org
